@@ -125,9 +125,11 @@ var namespacelibcamera =
     [ "V4L2SubdeviceCapability", "structlibcamera_1_1V4L2SubdeviceCapability.html", "structlibcamera_1_1V4L2SubdeviceCapability" ],
     [ "V4L2SubdeviceFormat", "structlibcamera_1_1V4L2SubdeviceFormat.html", "structlibcamera_1_1V4L2SubdeviceFormat" ],
     [ "V4L2VideoDevice", "classlibcamera_1_1V4L2VideoDevice.html", "classlibcamera_1_1V4L2VideoDevice" ],
+    [ "Vector", "classlibcamera_1_1Vector.html", "classlibcamera_1_1Vector" ],
     [ "YamlObject", "classlibcamera_1_1YamlObject.html", "classlibcamera_1_1YamlObject" ],
     [ "YamlParser", "classlibcamera_1_1YamlParser.html", null ],
     [ "ControlIdMap", "namespacelibcamera.html#aa331d4459b6d32bfcf9c1c6b865a41bf", null ],
+    [ "RGB", "namespacelibcamera.html#a9bcbbdc486cdc7466dec559b99c544a0", null ],
     [ "ConnectionType", "namespacelibcamera.html#ae2c8412791b9597d590a7d0b2c9e2919", [
       [ "ConnectionTypeAuto", "namespacelibcamera.html#ae2c8412791b9597d590a7d0b2c9e2919ae8d08355860ab248591945b563fb39f4", null ],
       [ "ConnectionTypeDirect", "namespacelibcamera.html#ae2c8412791b9597d590a7d0b2c9e2919a654040cc9784221ba0c421778f3f675b", null ],
@@ -202,9 +204,11 @@ var namespacelibcamera =
     [ "logSetStream", "namespacelibcamera.html#a0e15016b52a1d9cf09e21517bf67cb4a", null ],
     [ "logSetTarget", "namespacelibcamera.html#ab2fe53d88af8815d6e22008802bd195d", null ],
     [ "operator!", "namespacelibcamera.html#aab7c0788509ace93133168772907fb21", null ],
+    [ "operator!=", "namespacelibcamera.html#aaa48008ef5f18f39354e32074ef8a63f", null ],
     [ "operator&", "namespacelibcamera.html#ab4c2f17a92c7c0cf81cab4b4b394d898", null ],
     [ "operator&=", "namespacelibcamera.html#a33307ddc15300100702598b127828e07", null ],
     [ "operator*", "namespacelibcamera.html#a36e530b5c24e217eb73b37621efa0056", null ],
+    [ "operator*", "namespacelibcamera.html#aadd86e5e4828679c140b9466397be0f1", null ],
     [ "operator*", "namespacelibcamera.html#ac077ddd7639033ada89a6b9af54cf109", null ],
     [ "operator*", "namespacelibcamera.html#aa3714da6d73d2c21990f5900cbabe37d", null ],
     [ "operator*", "namespacelibcamera.html#a67ccaafd34c635aa736d061542f9f87c", null ],
@@ -238,6 +242,7 @@ var namespacelibcamera =
     [ "operator==", "namespacelibcamera.html#ac999efe2c1913ea8cdcfefa4f9ded359", null ],
     [ "operator==", "namespacelibcamera.html#a0423b1d8e6dc206e717030a9d1fa71cf", null ],
     [ "operator==", "namespacelibcamera.html#abf523068ee1f081bee8d1dd906c7d128", null ],
+    [ "operator==", "namespacelibcamera.html#aced6783564bda1a14f40cb72fe9edc74", null ],
     [ "operator^", "namespacelibcamera.html#a906d269e702bba58517f6aced239af10", null ],
     [ "operator^=", "namespacelibcamera.html#ae9daa244428448fb0537370cb0bb2449", null ],
     [ "operator|", "namespacelibcamera.html#a7a895199ceb604882ac29ef46fd97171", null ],
