@@ -1,5 +1,19 @@
 var NAVTREEINDEX4 =
 {
+"classlibcamera_1_1FrameBufferAllocator.html":[7,0,0,44],
+"classlibcamera_1_1FrameBufferAllocator.html#a184749ea64aeba195bd7c8a880311cd4":[6,0,0,45,4],
+"classlibcamera_1_1FrameBufferAllocator.html#a184749ea64aeba195bd7c8a880311cd4":[7,0,0,44,4],
+"classlibcamera_1_1FrameBufferAllocator.html#a1d115534f49614e3466f5e86fbc43f2a":[6,0,0,45,1],
+"classlibcamera_1_1FrameBufferAllocator.html#a1d115534f49614e3466f5e86fbc43f2a":[7,0,0,44,1],
+"classlibcamera_1_1FrameBufferAllocator.html#a7e35d2d59174137dfd3395b1e802a148":[6,0,0,45,2],
+"classlibcamera_1_1FrameBufferAllocator.html#a7e35d2d59174137dfd3395b1e802a148":[7,0,0,44,2],
+"classlibcamera_1_1FrameBufferAllocator.html#a8207ce42ed29ebae26378357c2054ee7":[6,0,0,45,3],
+"classlibcamera_1_1FrameBufferAllocator.html#a8207ce42ed29ebae26378357c2054ee7":[7,0,0,44,3],
+"classlibcamera_1_1FrameBufferAllocator.html#ab66590d49bdb5dba848a74604f0b2597":[6,0,0,45,0],
+"classlibcamera_1_1FrameBufferAllocator.html#ab66590d49bdb5dba848a74604f0b2597":[7,0,0,44,0],
+"classlibcamera_1_1FrameBuffer_1_1Private.html":[6,0,0,44,1],
+"classlibcamera_1_1FrameBuffer_1_1Private.html":[7,0,0,43,1],
+"classlibcamera_1_1FrameBuffer_1_1Private.html#a30efe76aa77087961accb7d050c898ba":[6,0,0,44,1,1],
 "classlibcamera_1_1FrameBuffer_1_1Private.html#a30efe76aa77087961accb7d050c898ba":[7,0,0,43,1,1],
 "classlibcamera_1_1FrameBuffer_1_1Private.html#a607147c1d87defee476165493487f2d3":[6,0,0,44,1,3],
 "classlibcamera_1_1FrameBuffer_1_1Private.html#a607147c1d87defee476165493487f2d3":[7,0,0,43,1,3],
@@ -137,24 +151,22 @@ var NAVTREEINDEX4 =
 "classlibcamera_1_1LogCategory.html#ad14ecd4224958a54a49aa1746c7762a6":[7,0,0,63,2],
 "classlibcamera_1_1LogMessage.html":[6,0,0,67],
 "classlibcamera_1_1LogMessage.html":[7,0,0,66],
-"classlibcamera_1_1LogMessage.html#a1aed7ff6f5ba10690c409adfc9ed46c6":[6,0,0,67,8],
-"classlibcamera_1_1LogMessage.html#a1aed7ff6f5ba10690c409adfc9ed46c6":[7,0,0,66,8],
-"classlibcamera_1_1LogMessage.html#a22a9f986d8fb207c641a0f9f2a2b57fa":[6,0,0,67,2],
-"classlibcamera_1_1LogMessage.html#a22a9f986d8fb207c641a0f9f2a2b57fa":[7,0,0,66,2],
-"classlibcamera_1_1LogMessage.html#a2f91139813ad00f1266c5df874a627fe":[6,0,0,67,6],
-"classlibcamera_1_1LogMessage.html#a2f91139813ad00f1266c5df874a627fe":[7,0,0,66,6],
-"classlibcamera_1_1LogMessage.html#a3bc0a00af4837c77b6580b4263e5f016":[6,0,0,67,5],
-"classlibcamera_1_1LogMessage.html#a3bc0a00af4837c77b6580b4263e5f016":[7,0,0,66,5],
-"classlibcamera_1_1LogMessage.html#a4bf00a52f46e00065798c2726ebce5ea":[6,0,0,67,0],
-"classlibcamera_1_1LogMessage.html#a4bf00a52f46e00065798c2726ebce5ea":[7,0,0,66,0],
-"classlibcamera_1_1LogMessage.html#a53182ce9cb5a240d62ea6e3765c15c1c":[6,0,0,67,1],
-"classlibcamera_1_1LogMessage.html#a53182ce9cb5a240d62ea6e3765c15c1c":[7,0,0,66,1],
-"classlibcamera_1_1LogMessage.html#a8b8d83ee0ec5e40c80e23cf6319a04ef":[6,0,0,67,3],
-"classlibcamera_1_1LogMessage.html#a8b8d83ee0ec5e40c80e23cf6319a04ef":[7,0,0,66,3],
-"classlibcamera_1_1LogMessage.html#abe2ee89bf5c905d9163455a3bc88814a":[6,0,0,67,4],
-"classlibcamera_1_1LogMessage.html#abe2ee89bf5c905d9163455a3bc88814a":[7,0,0,66,4],
-"classlibcamera_1_1LogMessage.html#acdf50e29aa06bb64ffc7386d27a170d8":[6,0,0,67,7],
-"classlibcamera_1_1LogMessage.html#acdf50e29aa06bb64ffc7386d27a170d8":[7,0,0,66,7],
+"classlibcamera_1_1LogMessage.html#a1aed7ff6f5ba10690c409adfc9ed46c6":[6,0,0,67,7],
+"classlibcamera_1_1LogMessage.html#a1aed7ff6f5ba10690c409adfc9ed46c6":[7,0,0,66,7],
+"classlibcamera_1_1LogMessage.html#a22a9f986d8fb207c641a0f9f2a2b57fa":[6,0,0,67,1],
+"classlibcamera_1_1LogMessage.html#a22a9f986d8fb207c641a0f9f2a2b57fa":[7,0,0,66,1],
+"classlibcamera_1_1LogMessage.html#a2f91139813ad00f1266c5df874a627fe":[6,0,0,67,5],
+"classlibcamera_1_1LogMessage.html#a2f91139813ad00f1266c5df874a627fe":[7,0,0,66,5],
+"classlibcamera_1_1LogMessage.html#a3bc0a00af4837c77b6580b4263e5f016":[6,0,0,67,4],
+"classlibcamera_1_1LogMessage.html#a3bc0a00af4837c77b6580b4263e5f016":[7,0,0,66,4],
+"classlibcamera_1_1LogMessage.html#a7d8f69f1cef4734949fc25e93516aadf":[6,0,0,67,0],
+"classlibcamera_1_1LogMessage.html#a7d8f69f1cef4734949fc25e93516aadf":[7,0,0,66,0],
+"classlibcamera_1_1LogMessage.html#a8b8d83ee0ec5e40c80e23cf6319a04ef":[6,0,0,67,2],
+"classlibcamera_1_1LogMessage.html#a8b8d83ee0ec5e40c80e23cf6319a04ef":[7,0,0,66,2],
+"classlibcamera_1_1LogMessage.html#abe2ee89bf5c905d9163455a3bc88814a":[6,0,0,67,3],
+"classlibcamera_1_1LogMessage.html#abe2ee89bf5c905d9163455a3bc88814a":[7,0,0,66,3],
+"classlibcamera_1_1LogMessage.html#acdf50e29aa06bb64ffc7386d27a170d8":[6,0,0,67,6],
+"classlibcamera_1_1LogMessage.html#acdf50e29aa06bb64ffc7386d27a170d8":[7,0,0,66,6],
 "classlibcamera_1_1LogOutput.html":[6,0,0,68],
 "classlibcamera_1_1LogOutput.html":[7,0,0,67],
 "classlibcamera_1_1LogOutput.html#a1538839b448d23ff5d016094697de800":[6,0,0,68,1],
@@ -227,27 +239,15 @@ var NAVTREEINDEX4 =
 "classlibcamera_1_1MappedFrameBuffer.html#ae557263e95a29b5e6eb277f289414a60":[7,0,0,69,0],
 "classlibcamera_1_1Matrix.html":[6,0,0,71],
 "classlibcamera_1_1Matrix.html":[7,0,0,70],
-"classlibcamera_1_1Matrix.html#a0f0d9a4f3bd54c8f54ae3bd11990eb88":[6,0,0,71,3],
-"classlibcamera_1_1Matrix.html#a0f0d9a4f3bd54c8f54ae3bd11990eb88":[7,0,0,70,3],
+"classlibcamera_1_1Matrix.html#a0898fb16e31600a9f5ac2ae50c179c75":[6,0,0,71,2],
+"classlibcamera_1_1Matrix.html#a0898fb16e31600a9f5ac2ae50c179c75":[7,0,0,70,2],
+"classlibcamera_1_1Matrix.html#a0f0d9a4f3bd54c8f54ae3bd11990eb88":[6,0,0,71,4],
+"classlibcamera_1_1Matrix.html#a0f0d9a4f3bd54c8f54ae3bd11990eb88":[7,0,0,70,4],
 "classlibcamera_1_1Matrix.html#a268e1d3563caf8f875eb0fcbb8692a32":[6,0,0,71,1],
 "classlibcamera_1_1Matrix.html#a268e1d3563caf8f875eb0fcbb8692a32":[7,0,0,70,1],
-"classlibcamera_1_1Matrix.html#a31b00ce56da70d2d8c2ef2691dcd6e53":[6,0,0,71,2],
-"classlibcamera_1_1Matrix.html#a31b00ce56da70d2d8c2ef2691dcd6e53":[7,0,0,70,2],
+"classlibcamera_1_1Matrix.html#a31b00ce56da70d2d8c2ef2691dcd6e53":[6,0,0,71,3],
+"classlibcamera_1_1Matrix.html#a31b00ce56da70d2d8c2ef2691dcd6e53":[7,0,0,70,3],
 "classlibcamera_1_1Matrix.html#a5352157305279408a9fdc20f7ace29c1":[6,0,0,71,0],
 "classlibcamera_1_1Matrix.html#a5352157305279408a9fdc20f7ace29c1":[7,0,0,70,0],
-"classlibcamera_1_1Matrix.html#a62740e9d1682960e5ec9ddefbb7b8cb8":[6,0,0,71,5],
-"classlibcamera_1_1Matrix.html#a62740e9d1682960e5ec9ddefbb7b8cb8":[7,0,0,70,5],
-"classlibcamera_1_1Matrix.html#ab6eeb2712e5270d2e9b961e97121a783":[6,0,0,71,4],
-"classlibcamera_1_1Matrix.html#ab6eeb2712e5270d2e9b961e97121a783":[7,0,0,70,4],
-"classlibcamera_1_1MediaBusFormatInfo.html":[6,0,0,72],
-"classlibcamera_1_1MediaBusFormatInfo.html":[7,0,0,71],
-"classlibcamera_1_1MediaBusFormatInfo.html#a38fb105d25e23f743dd559f6bf49ae3b":[6,0,0,72,6],
-"classlibcamera_1_1MediaBusFormatInfo.html#a38fb105d25e23f743dd559f6bf49ae3b":[7,0,0,71,6],
-"classlibcamera_1_1MediaBusFormatInfo.html#a447212f2d5b1b3dd75eca932f2c4c3d5":[6,0,0,72,1],
-"classlibcamera_1_1MediaBusFormatInfo.html#a447212f2d5b1b3dd75eca932f2c4c3d5":[7,0,0,71,1],
-"classlibcamera_1_1MediaBusFormatInfo.html#a7858e0da5a7be92255cf7abb8f4065cd":[6,0,0,72,3],
-"classlibcamera_1_1MediaBusFormatInfo.html#a7858e0da5a7be92255cf7abb8f4065cd":[7,0,0,71,3],
-"classlibcamera_1_1MediaBusFormatInfo.html#a8d07b876f5ce8ae5f6236f24fb616c4b":[6,0,0,72,5],
-"classlibcamera_1_1MediaBusFormatInfo.html#a8d07b876f5ce8ae5f6236f24fb616c4b":[7,0,0,71,5],
-"classlibcamera_1_1MediaBusFormatInfo.html#aa8ac57fc34eb05f61f0b65d2c728ecf6":[6,0,0,72,2]
+"classlibcamera_1_1Matrix.html#a62740e9d1682960e5ec9ddefbb7b8cb8":[6,0,0,71,6]
 };
