@@ -1,5 +1,19 @@
 var NAVTREEINDEX5 =
 {
+"classlibcamera_1_1Matrix.html#a62740e9d1682960e5ec9ddefbb7b8cb8":[7,0,0,70,6],
+"classlibcamera_1_1Matrix.html#ab6eeb2712e5270d2e9b961e97121a783":[6,0,0,71,5],
+"classlibcamera_1_1Matrix.html#ab6eeb2712e5270d2e9b961e97121a783":[7,0,0,70,5],
+"classlibcamera_1_1MediaBusFormatInfo.html":[6,0,0,72],
+"classlibcamera_1_1MediaBusFormatInfo.html":[7,0,0,71],
+"classlibcamera_1_1MediaBusFormatInfo.html#a38fb105d25e23f743dd559f6bf49ae3b":[6,0,0,72,6],
+"classlibcamera_1_1MediaBusFormatInfo.html#a38fb105d25e23f743dd559f6bf49ae3b":[7,0,0,71,6],
+"classlibcamera_1_1MediaBusFormatInfo.html#a447212f2d5b1b3dd75eca932f2c4c3d5":[6,0,0,72,1],
+"classlibcamera_1_1MediaBusFormatInfo.html#a447212f2d5b1b3dd75eca932f2c4c3d5":[7,0,0,71,1],
+"classlibcamera_1_1MediaBusFormatInfo.html#a7858e0da5a7be92255cf7abb8f4065cd":[6,0,0,72,3],
+"classlibcamera_1_1MediaBusFormatInfo.html#a7858e0da5a7be92255cf7abb8f4065cd":[7,0,0,71,3],
+"classlibcamera_1_1MediaBusFormatInfo.html#a8d07b876f5ce8ae5f6236f24fb616c4b":[6,0,0,72,5],
+"classlibcamera_1_1MediaBusFormatInfo.html#a8d07b876f5ce8ae5f6236f24fb616c4b":[7,0,0,71,5],
+"classlibcamera_1_1MediaBusFormatInfo.html#aa8ac57fc34eb05f61f0b65d2c728ecf6":[6,0,0,72,2],
 "classlibcamera_1_1MediaBusFormatInfo.html#aa8ac57fc34eb05f61f0b65d2c728ecf6":[7,0,0,71,2],
 "classlibcamera_1_1MediaBusFormatInfo.html#ac9449b337ce3778acecc77dc30c45082":[6,0,0,72,4],
 "classlibcamera_1_1MediaBusFormatInfo.html#ac9449b337ce3778acecc77dc30c45082":[7,0,0,71,4],
@@ -57,6 +71,8 @@ var NAVTREEINDEX5 =
 "classlibcamera_1_1MediaDevice.html#afa3b83f5f3fe2af9b4a8b5d518518386":[7,0,0,72,18],
 "classlibcamera_1_1MediaEntity.html":[6,0,0,74],
 "classlibcamera_1_1MediaEntity.html":[7,0,0,73],
+"classlibcamera_1_1MediaEntity.html#a1094b9c0b76005d9854672a0bc757164":[6,0,0,74,1],
+"classlibcamera_1_1MediaEntity.html#a1094b9c0b76005d9854672a0bc757164":[7,0,0,73,1],
 "classlibcamera_1_1MediaEntity.html#a1ff953f95e47de297e4aa6e3b0bcb265":[6,0,0,74,12],
 "classlibcamera_1_1MediaEntity.html#a1ff953f95e47de297e4aa6e3b0bcb265":[7,0,0,73,12],
 "classlibcamera_1_1MediaEntity.html#a686f2fff310e6802d1778a9ae32c6473":[6,0,0,74,4],
@@ -87,8 +103,6 @@ var NAVTREEINDEX5 =
 "classlibcamera_1_1MediaEntity.html#ad0b52e7e1ad73770f23a6a9445c87572":[7,0,0,73,9],
 "classlibcamera_1_1MediaEntity.html#ad623b7550d351b5b813e303dd28985d1":[6,0,0,74,3],
 "classlibcamera_1_1MediaEntity.html#ad623b7550d351b5b813e303dd28985d1":[7,0,0,73,3],
-"classlibcamera_1_1MediaEntity.html#ad89e255c9bc1b90f75ce49b02a253a26":[6,0,0,74,1],
-"classlibcamera_1_1MediaEntity.html#ad89e255c9bc1b90f75ce49b02a253a26":[7,0,0,73,1],
 "classlibcamera_1_1MediaEntity.html#afc48af8e052b6436492eb9196abced71":[6,0,0,74,11],
 "classlibcamera_1_1MediaEntity.html#afc48af8e052b6436492eb9196abced71":[7,0,0,73,11],
 "classlibcamera_1_1MediaLink.html":[6,0,0,75],
@@ -203,6 +217,8 @@ var NAVTREEINDEX5 =
 "classlibcamera_1_1PipelineHandler.html#a02e261e7a50d560b6a28ae39b3d6e760":[7,0,0,83,24],
 "classlibcamera_1_1PipelineHandler.html#a15c651ee1fb80a7564dae0fcf8526aab":[6,0,0,84,4],
 "classlibcamera_1_1PipelineHandler.html#a15c651ee1fb80a7564dae0fcf8526aab":[7,0,0,83,4],
+"classlibcamera_1_1PipelineHandler.html#a2166be16295df6167347061ecd172cd0":[6,0,0,84,8],
+"classlibcamera_1_1PipelineHandler.html#a2166be16295df6167347061ecd172cd0":[7,0,0,83,8],
 "classlibcamera_1_1PipelineHandler.html#a25b18b2f7a20e726485880cae509204d":[6,0,0,84,13],
 "classlibcamera_1_1PipelineHandler.html#a25b18b2f7a20e726485880cae509204d":[7,0,0,83,13],
 "classlibcamera_1_1PipelineHandler.html#a27a346008886d65a7bdd4b2569049e8b":[6,0,0,84,15],
@@ -219,8 +235,6 @@ var NAVTREEINDEX5 =
 "classlibcamera_1_1PipelineHandler.html#a568751defdba3b1b1a22b697a5947d66":[7,0,0,83,17],
 "classlibcamera_1_1PipelineHandler.html#a57ddfa7d422aefd4f99a382d6d711ffa":[6,0,0,84,1],
 "classlibcamera_1_1PipelineHandler.html#a57ddfa7d422aefd4f99a382d6d711ffa":[7,0,0,83,1],
-"classlibcamera_1_1PipelineHandler.html#a6d96ced1bc15f35c8c7065a312931e30":[6,0,0,84,8],
-"classlibcamera_1_1PipelineHandler.html#a6d96ced1bc15f35c8c7065a312931e30":[7,0,0,83,8],
 "classlibcamera_1_1PipelineHandler.html#a6f7d619636c8988aeed3afd43ce8ed02":[6,0,0,84,2],
 "classlibcamera_1_1PipelineHandler.html#a6f7d619636c8988aeed3afd43ce8ed02":[7,0,0,83,2],
 "classlibcamera_1_1PipelineHandler.html#a746e0a04c571cec253e601eb72c732e7":[6,0,0,84,14],
@@ -235,19 +249,5 @@ var NAVTREEINDEX5 =
 "classlibcamera_1_1PipelineHandler.html#a9ccd6a33ee882ec35d8ef88b0efcc136":[7,0,0,83,22],
 "classlibcamera_1_1PipelineHandler.html#aa0b8456fa90a7395aab6452ce800a160":[6,0,0,84,5],
 "classlibcamera_1_1PipelineHandler.html#aa0b8456fa90a7395aab6452ce800a160":[7,0,0,83,5],
-"classlibcamera_1_1PipelineHandler.html#aa82dffe399ac974ecb375cbb2a2074dd":[6,0,0,84,16],
-"classlibcamera_1_1PipelineHandler.html#aa82dffe399ac974ecb375cbb2a2074dd":[7,0,0,83,16],
-"classlibcamera_1_1PipelineHandler.html#aac41ce2a1957534be1d1dd77145218e6":[6,0,0,84,12],
-"classlibcamera_1_1PipelineHandler.html#aac41ce2a1957534be1d1dd77145218e6":[7,0,0,83,12],
-"classlibcamera_1_1PipelineHandler.html#ab30b037abfb09bd548c53c9f9196a184":[6,0,0,84,23],
-"classlibcamera_1_1PipelineHandler.html#ab30b037abfb09bd548c53c9f9196a184":[7,0,0,83,23],
-"classlibcamera_1_1PipelineHandler.html#ab86c9d188108b3926a15502139f356af":[6,0,0,84,10],
-"classlibcamera_1_1PipelineHandler.html#ab86c9d188108b3926a15502139f356af":[7,0,0,83,10],
-"classlibcamera_1_1PipelineHandler.html#abacaf700d3d1d9e52900edfbe5802498":[6,0,0,84,11],
-"classlibcamera_1_1PipelineHandler.html#abacaf700d3d1d9e52900edfbe5802498":[7,0,0,83,11],
-"classlibcamera_1_1PipelineHandler.html#ad388abbf81afa644f366326dc41d7b63":[6,0,0,84,6],
-"classlibcamera_1_1PipelineHandler.html#ad388abbf81afa644f366326dc41d7b63":[7,0,0,83,6],
-"classlibcamera_1_1PipelineHandler.html#aea4680f0d03892ba57d64750d4655e0c":[6,0,0,84,9],
-"classlibcamera_1_1PipelineHandler.html#aea4680f0d03892ba57d64750d4655e0c":[7,0,0,83,9],
-"classlibcamera_1_1PipelineHandler.html#aead119b03920f468fa3bd091bfd65e5b":[6,0,0,84,20]
+"classlibcamera_1_1PipelineHandler.html#aa82dffe399ac974ecb375cbb2a2074dd":[6,0,0,84,16]
 };
