@@ -24,16 +24,17 @@ var searchData=
   ['validator_21',['validator',['../classlibcamera_1_1Camera_1_1Private.html#af42d5796d0bc8e36ff0cd5f0e0eb7443',1,'libcamera::Camera::Private']]],
   ['values_22',['values',['../classlibcamera_1_1ControlInfo.html#a1ce70ac404f45eaf9bb0386918aaedca',1,'libcamera::ControlInfo']]],
   ['vblankdelay_23',['vblankDelay',['../structlibcamera_1_1CameraSensorProperties_1_1SensorDelays.html#a9ca4dfefbc344433764e2bc033b4ad48',1,'libcamera::CameraSensorProperties::SensorDelays']]],
-  ['vector_24',['Vector',['../classlibcamera_1_1ipa_1_1Vector.html',1,'libcamera::ipa::Vector&lt; T, Rows &gt;'],['../classlibcamera_1_1ipa_1_1Vector.html#a568fba2456dfadd26222457454216407',1,'libcamera::ipa::Vector::Vector()=default'],['../classlibcamera_1_1ipa_1_1Vector.html#aabec9e05a1a46374c8e51a1869b09bcc',1,'libcamera::ipa::Vector::Vector(T scalar)'],['../classlibcamera_1_1ipa_1_1Vector.html#a93f8b9fa92d7cce35697be890e8a0cf0',1,'libcamera::ipa::Vector::Vector(const std::array&lt; T, Rows &gt; &amp;data)']]],
+  ['vector_24',['Vector',['../classlibcamera_1_1Vector.html',1,'libcamera::Vector&lt; T, Rows &gt;'],['../classlibcamera_1_1Vector.html#a98073779cde78cde03da4f575fc56257',1,'libcamera::Vector::Vector()=default'],['../classlibcamera_1_1Vector.html#a607fb9af7a28b1427d6d4443a52a07c7',1,'libcamera::Vector::Vector(T scalar)'],['../classlibcamera_1_1Vector.html#a2f8ddd4a967c819967ca20ded11b460c',1,'libcamera::Vector::Vector(const std::array&lt; T, Rows &gt; &amp;data)']]],
   ['vector_2eh_25',['vector.h',['../vector_8h.html',1,'']]],
-  ['vector_3c_20double_2c_202_20_3e_26',['Vector&lt; double, 2 &gt;',['../classlibcamera_1_1ipa_1_1Vector.html',1,'libcamera::ipa']]],
-  ['vector_3c_20t_2c_203_20_3e_27',['Vector&lt; T, 3 &gt;',['../classlibcamera_1_1ipa_1_1Vector.html',1,'libcamera::ipa']]],
-  ['vendor_28',['vendor',['../classlibcamera_1_1ControlId.html#aba34f493d8313c60930c9d9cce61922c',1,'libcamera::ControlId']]],
-  ['verify_29',['verify',['../classlibcamera_1_1PubKey.html#a959683b12bed8b7ec178c8b0b72fe6c5',1,'libcamera::PubKey']]],
-  ['version_30',['version',['../structlibcamera_1_1ipa__controls__header.html#a3a765c275ff9ca1fbeb6c30710991735',1,'libcamera::ipa_controls_header::version'],['../classlibcamera_1_1CameraManager.html#a7a9c0aefeac0ff1e3a42da3072ab0a97',1,'libcamera::CameraManager::version()'],['../classlibcamera_1_1MediaDevice.html#af335184ee6174ea68747d32955d6f9c8',1,'libcamera::MediaDevice::version()']]],
-  ['verticalsubsampling_31',['verticalSubSampling',['../structlibcamera_1_1PixelFormatInfo_1_1Plane.html#a718acb445ae5af9825489f728c78db9c',1,'libcamera::PixelFormatInfo::Plane']]],
-  ['vflip_32',['VFlip',['../namespacelibcamera.html#a371b6d17d531b85c035c4e889b116571a0b5d83f7ecb707aee4151b6575ca5af7',1,'libcamera']]],
-  ['videorecording_33',['VideoRecording',['../namespacelibcamera.html#a295d1f5e7828d95c0b0aabc0a8baac03ae1ff48054403b149f903eb40e16ec86e',1,'libcamera']]],
-  ['viewfinder_34',['Viewfinder',['../namespacelibcamera.html#a295d1f5e7828d95c0b0aabc0a8baac03a30b5987e4c03f83a7e1909e4f72eefd4',1,'libcamera']]],
-  ['vstep_35',['vStep',['../classlibcamera_1_1SizeRange.html#ae00aab56b782a1a098f6fe1dcc2d0d8a',1,'libcamera::SizeRange']]]
+  ['vector_3c_20double_2c_202_20_3e_26',['Vector&lt; double, 2 &gt;',['../classlibcamera_1_1Vector.html',1,'libcamera']]],
+  ['vector_3c_20t_2c_203_20_3e_27',['Vector&lt; T, 3 &gt;',['../classlibcamera_1_1Vector.html',1,'libcamera']]],
+  ['vector_3c_20t_2c_203_20_3e_3c_20double_20_3e_28',['Vector&lt; T, 3 &gt;&lt; double &gt;',['../classlibcamera_1_1Vector.html',1,'libcamera']]],
+  ['vendor_29',['vendor',['../classlibcamera_1_1ControlId.html#aba34f493d8313c60930c9d9cce61922c',1,'libcamera::ControlId']]],
+  ['verify_30',['verify',['../classlibcamera_1_1PubKey.html#a959683b12bed8b7ec178c8b0b72fe6c5',1,'libcamera::PubKey']]],
+  ['version_31',['version',['../structlibcamera_1_1ipa__controls__header.html#a3a765c275ff9ca1fbeb6c30710991735',1,'libcamera::ipa_controls_header::version'],['../classlibcamera_1_1CameraManager.html#a7a9c0aefeac0ff1e3a42da3072ab0a97',1,'libcamera::CameraManager::version()'],['../classlibcamera_1_1MediaDevice.html#af335184ee6174ea68747d32955d6f9c8',1,'libcamera::MediaDevice::version()']]],
+  ['verticalsubsampling_32',['verticalSubSampling',['../structlibcamera_1_1PixelFormatInfo_1_1Plane.html#a718acb445ae5af9825489f728c78db9c',1,'libcamera::PixelFormatInfo::Plane']]],
+  ['vflip_33',['VFlip',['../namespacelibcamera.html#a371b6d17d531b85c035c4e889b116571a0b5d83f7ecb707aee4151b6575ca5af7',1,'libcamera']]],
+  ['videorecording_34',['VideoRecording',['../namespacelibcamera.html#a295d1f5e7828d95c0b0aabc0a8baac03ae1ff48054403b149f903eb40e16ec86e',1,'libcamera']]],
+  ['viewfinder_35',['Viewfinder',['../namespacelibcamera.html#a295d1f5e7828d95c0b0aabc0a8baac03a30b5987e4c03f83a7e1909e4f72eefd4',1,'libcamera']]],
+  ['vstep_36',['vStep',['../classlibcamera_1_1SizeRange.html#ae00aab56b782a1a098f6fe1dcc2d0d8a',1,'libcamera::SizeRange']]]
 ];
