@@ -7,7 +7,7 @@ var searchData=
   ['mappedframebuffer_4',['MappedFrameBuffer',['../classlibcamera_1_1MappedFrameBuffer.html#a656d42eef1b5847073197a58cf860bf2',1,'libcamera::MappedFrameBuffer']]],
   ['match_5',['match',['../classlibcamera_1_1DeviceMatch.html#ae9923a86604c13eb08c0273b95d0a923',1,'libcamera::DeviceMatch::match()'],['../classlibcamera_1_1IPAModule.html#aeff066789ce1cfd94e14169cdcd6c7c7',1,'libcamera::IPAModule::match()'],['../classlibcamera_1_1PipelineHandler.html#a746e0a04c571cec253e601eb72c732e7',1,'libcamera::PipelineHandler::match()']]],
   ['matrix_6',['Matrix',['../classlibcamera_1_1Matrix.html#a5352157305279408a9fdc20f7ace29c1',1,'libcamera::Matrix::Matrix()'],['../classlibcamera_1_1Matrix.html#a268e1d3563caf8f875eb0fcbb8692a32',1,'libcamera::Matrix::Matrix(const std::array&lt; T, Rows *Cols &gt; &amp;data)']]],
-  ['max_7',['max',['../classlibcamera_1_1ControlInfo.html#a967744bc7e296f83938f1bf510ef2a90',1,'libcamera::ControlInfo::max()'],['../classlibcamera_1_1ipa_1_1Vector.html#a0896e1ddb10efc42aae59f386d714cab',1,'libcamera::ipa::Vector::max(const Vector &amp;other) const'],['../classlibcamera_1_1ipa_1_1Vector.html#a6359e499bbbd224d44c57e8efb8aaf65',1,'libcamera::ipa::Vector::max(T scalar) const']]],
+  ['max_7',['max',['../classlibcamera_1_1ControlInfo.html#a967744bc7e296f83938f1bf510ef2a90',1,'libcamera::ControlInfo::max()'],['../classlibcamera_1_1Vector.html#a64e0831f44aef4f36d5880bfa89b6eeb',1,'libcamera::Vector::max(const Vector &amp;other) const'],['../classlibcamera_1_1Vector.html#ac28348deda135f76a444156a3ae0ebbf',1,'libcamera::Vector::max(T scalar) const']]],
   ['maxexposuretime_8',['maxExposureTime',['../classlibcamera_1_1ipa_1_1ExposureModeHelper.html#aa7c6ddc50b97df289af9aaf6134c6b55',1,'libcamera::ipa::ExposureModeHelper']]],
   ['maxgain_9',['maxGain',['../classlibcamera_1_1ipa_1_1ExposureModeHelper.html#a9e2f22b1a05797ee9603f81b40c5bdf1',1,'libcamera::ipa::ExposureModeHelper']]],
   ['mbuscodes_10',['mbusCodes',['../classlibcamera_1_1CameraSensor.html#a8f2f09afd51003f186bbf8afd412a25a',1,'libcamera::CameraSensor']]],
@@ -18,7 +18,7 @@ var searchData=
   ['message_15',['Message',['../classlibcamera_1_1Message.html#a820b1e559680365eef4d156915331e81',1,'libcamera::Message']]],
   ['message_16',['message',['../classlibcamera_1_1EventNotifier.html#a83550c524a9bcc0ea582e876ca43c04d',1,'libcamera::EventNotifier::message()'],['../classlibcamera_1_1Object.html#a5328cab1412743716aa2748eeded8e80',1,'libcamera::Object::message()'],['../classlibcamera_1_1Timer.html#a3ed22e72f2b3001a17e8aedcc6374c0c',1,'libcamera::Timer::message()']]],
   ['metadata_17',['metadata',['../classlibcamera_1_1FrameBuffer.html#a95daecbcca64c22e241bbbe29ebdf67e',1,'libcamera::FrameBuffer::metadata()'],['../classlibcamera_1_1FrameBuffer_1_1Private.html#ae18d68743f5e9d102cc3b639f9a5c6ad',1,'libcamera::FrameBuffer::Private::metadata()'],['../classlibcamera_1_1Request.html#a6c62e45e8d9c0d1dbe37c0f95e871994',1,'libcamera::Request::metadata()']]],
-  ['min_18',['min',['../classlibcamera_1_1ControlInfo.html#af4105da1b9e04e17b8d96a1df3927e9d',1,'libcamera::ControlInfo::min()'],['../classlibcamera_1_1ipa_1_1Vector.html#af62c0338f44f29d866849b05b69187bc',1,'libcamera::ipa::Vector::min(const Vector &amp;other) const'],['../classlibcamera_1_1ipa_1_1Vector.html#a46679acdc8a6b4ed1d89d82bd855c446',1,'libcamera::ipa::Vector::min(T scalar) const']]],
+  ['min_18',['min',['../classlibcamera_1_1ControlInfo.html#af4105da1b9e04e17b8d96a1df3927e9d',1,'libcamera::ControlInfo::min()'],['../classlibcamera_1_1Vector.html#a37739dae0f7c1deeb16c339aa0052614',1,'libcamera::Vector::min(const Vector &amp;other) const'],['../classlibcamera_1_1Vector.html#a63e09fc539b2d9d1ff2fd9a60ae11a2d',1,'libcamera::Vector::min(T scalar) const']]],
   ['minexposuretime_19',['minExposureTime',['../classlibcamera_1_1ipa_1_1ExposureModeHelper.html#a27fd5cc9c132c8ab659c4da049ce5f5b',1,'libcamera::ipa::ExposureModeHelper']]],
   ['mingain_20',['minGain',['../classlibcamera_1_1ipa_1_1ExposureModeHelper.html#a97dc0902658d837b1cbe0793a7e133f6',1,'libcamera::ipa::ExposureModeHelper']]],
   ['model_21',['model',['../classlibcamera_1_1CameraLens.html#a1bd1ec1324fb3fcb10096ff3ef088ff3',1,'libcamera::CameraLens::model()'],['../classlibcamera_1_1CameraSensor.html#a190da5e09fac3d44238cfeae1933e7d9',1,'libcamera::CameraSensor::model()'],['../classlibcamera_1_1MediaDevice.html#adadfeebec081f183b703bd72c102791e',1,'libcamera::MediaDevice::model()'],['../classlibcamera_1_1V4L2Subdevice.html#ac8e06bbad91b294a1ac6fe4568986b9b',1,'libcamera::V4L2Subdevice::model()']]],
